@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import os
 import textwrap
 from argparse import FileType
 
@@ -16,12 +17,17 @@ from httpie.cli.constants import (BASE_OUTPUT_OPTIONS, DEFAULT_FORMAT_OPTIONS,
                                   SORTED_FORMAT_OPTIONS_STRING,
                                   UNSORTED_FORMAT_OPTIONS_STRING, RequestType)
 from httpie.cli.options import ParserSpec, Qualifiers, to_argparse
-from httpie.output.formatters.colors import (AUTO_STYLE, DEFAULT_STYLE,
+from httpie.output.formatters.colors import (AUTO_STYLE, DEFAULT_STYLE, BUNDLED_STYLES,
                                              get_available_styles)
 from httpie.plugins.builtin import BuiltinAuthPlugin
 from httpie.plugins.registry import plugin_manager
-from httpie.sessions import DEFAULT_SESSIONS_DIR
-from httpie.ssl_ import AVAILABLE_SSL_VERSION_ARG_MAPPING, DEFAULT_SSL_CIPHERS
+from httpie.ssl_ import AVAILABLE_SSL_VERSION_ARG_MAPPING, DEFAULT_SSL_CIPHERS_STRING
+
+
+# Man pages are static (built when making a release).
+# We use this check to not include generated, system-specific information there (e.g., default --ciphers).
+IS_MAN_PAGE = bool(os.environ.get('HTTPIE_BUILDING_MAN_PAGES'))
+
 
 options = ParserSpec(
     'http',
@@ -29,18 +35,19 @@ options = ParserSpec(
     epilog="""
     For every --OPTION there is also a --no-OPTION that reverts OPTION
     to its default value.
-    Suggestions and bug reports are greatly appreciated:
-        https://github.com/httpie/httpie/issues
-    """,
-)
 
+    Suggestions and bug reports are greatly appreciated:
+        https://github.com/httpie/cli/issues
+    """,
+    source_file=__file__
+)
 
 #######################################################################
 # Positional arguments.
 #######################################################################
 
 positional_arguments = options.add_group(
-    'Positional Arguments',
+    'Positional arguments',
     description="""
     These arguments come after any flags and in the order they are listed here.
     Only URL is required.
@@ -52,6 +59,7 @@ positional_arguments.add_argument(
     metavar='METHOD',
     nargs=Qualifiers.OPTIONAL,
     default=None,
+    short_help='The HTTP method to be used for the request (GET, POST, PUT, DELETE, ...).',
     help="""
     The HTTP method to be used for the request (GET, POST, PUT, DELETE, ...).
 
@@ -66,9 +74,10 @@ positional_arguments.add_argument(
 positional_arguments.add_argument(
     dest='url',
     metavar='URL',
+    short_help='The request URL.',
     help="""
-    The scheme defaults to 'http://' if the URL does not include one.
-    (You can override this with: --default-scheme=https)
+    The request URL. Scheme defaults to 'http://' if the URL
+    does not include one. (You can override this with: --default-scheme=http/https)
 
     You can also use a shorthand for localhost
 
@@ -83,6 +92,17 @@ positional_arguments.add_argument(
     nargs=Qualifiers.ZERO_OR_MORE,
     default=None,
     type=KeyValueArgType(*SEPARATOR_GROUP_ALL_ITEMS),
+    short_help=(
+        'HTTPie’s request items syntax for specifying HTTP headers, JSON/Form'
+        'data, files, and URL parameters.'
+    ),
+    nested_options=[
+        ('HTTP Headers', 'Name:Value', 'Arbitrary HTTP header, e.g X-API-Token:123'),
+        ('URL Parameters', 'name==value', 'Querystring parameter to the URL, e.g limit==50'),
+        ('Data Fields', 'field=value', 'Data fields to be serialized as JSON (default) or Form Data (with --form)'),
+        ('Raw JSON Fields', 'field:=json', 'Data field for real JSON types.'),
+        ('File upload Fields', 'field@/dir/file', 'Path field for uploading a file.'),
+    ],
     help=r"""
     Optional key-value pairs to be included in the request. The separator used
     determines the type:
@@ -128,7 +148,7 @@ positional_arguments.add_argument(
 # Content type.
 #######################################################################
 
-content_types = options.add_group('Predefined Content Types')
+content_types = options.add_group('Predefined content types')
 
 content_types.add_argument(
     '--json',
@@ -136,6 +156,7 @@ content_types.add_argument(
     action='store_const',
     const=RequestType.JSON,
     dest='request_type',
+    short_help='(default) Serialize data items from the command line as a JSON object.',
     help="""
     (default) Data items from the command line are serialized as a JSON object.
     The Content-Type and Accept headers are set to application/json
@@ -149,6 +170,7 @@ content_types.add_argument(
     action='store_const',
     const=RequestType.FORM,
     dest='request_type',
+    short_help='Serialize data items from the command line as form field data.',
     help="""
     Data items from the command line are serialized as form fields.
 
@@ -163,22 +185,21 @@ content_types.add_argument(
     action='store_const',
     const=RequestType.MULTIPART,
     dest='request_type',
-    help="""
-    Similar to --form, but always sends a multipart/form-data
-    request (i.e., even without files).
-
-    """,
+    short_help=(
+        'Similar to --form, but always sends a multipart/form-data '
+        'request (i.e., even without files).'
+    )
 )
 content_types.add_argument(
     '--boundary',
-    help="""
-    Specify a custom boundary string for multipart/form-data requests.
-    Only has effect only together with --form.
-
-    """,
+    short_help=(
+        'Specify a custom boundary string for multipart/form-data requests. '
+        'Only has effect only together with --form.'
+    )
 )
 content_types.add_argument(
     '--raw',
+    short_help='Pass raw request data without extra processing.',
     help="""
     This option allows you to pass raw request data without extra processing
     (as opposed to the structured request items syntax):
@@ -201,13 +222,14 @@ content_types.add_argument(
 # Content processing.
 #######################################################################
 
-processing_options = options.add_group('Content Processing Options')
+processing_options = options.add_group('Content processing options')
 
 processing_options.add_argument(
     '--compress',
     '-x',
     action='count',
     default=0,
+    short_help='Compress the content with Deflate algorithm.',
     help="""
     Content compressed (encoded) with Deflate algorithm.
     The Content-Encoding header is set to deflate.
@@ -218,27 +240,39 @@ processing_options.add_argument(
     """,
 )
 
+
 #######################################################################
 # Output processing
 #######################################################################
 
 
-def format_style_help(available_styles):
-    return """
+def format_style_help(available_styles, *, isolation_mode: bool = False):
+    text = """
     Output coloring style (default is "{default}"). It can be one of:
 
         {available_styles}
+    """
+    if isolation_mode:
+        text += '\n\n'
+        text += 'For finding out all available styles in your system, try:\n\n'
+        text += '    $ http --style\n'
+    text += textwrap.dedent("""
+        The "{auto_style}" style follows your terminal's ANSI color styles.
+        For non-{auto_style} styles to work properly, please make sure that the
+        $TERM environment variable is set to "xterm-256color" or similar
+        (e.g., via `export TERM=xterm-256color' in your ~/.bashrc).
+    """)
 
-    The "{auto_style}" style follows your terminal's ANSI color styles.
-    For non-{auto_style} styles to work properly, please make sure that the
-    $TERM environment variable is set to "xterm-256color" or similar
-    (e.g., via `export TERM=xterm-256color' in your ~/.bashrc).
-    """.format(
+    if isolation_mode:
+        available_styles = sorted(BUNDLED_STYLES)
+
+    available_styles_text = '\n'.join(
+        f'    {line.strip()}'
+        for line in textwrap.wrap(', '.join(available_styles), 60)
+    ).strip()
+    return text.format(
         default=DEFAULT_STYLE,
-        available_styles='\n'.join(
-            f'        {line.strip()}'
-            for line in textwrap.wrap(', '.join(available_styles), 60)
-        ).strip(),
+        available_styles=available_styles_text,
         auto_style=AUTO_STYLE,
     )
 
@@ -254,13 +288,14 @@ _unsorted_kwargs = {
     'dest': 'format_options',
 }
 
-output_processing = options.add_group('Output Processing')
+output_processing = options.add_group('Output processing')
 
 output_processing.add_argument(
     '--pretty',
     dest='prettify',
     default=PRETTY_STDOUT_TTY_ONLY,
     choices=sorted(PRETTY_MAP.keys()),
+    short_help='Control the processing of console outputs.',
     help="""
     Controls output processing. The value can be "none" to not prettify
     the output (default for redirected output), "all" to apply both colors
@@ -276,6 +311,7 @@ output_processing.add_argument(
     default=DEFAULT_STYLE,
     action='lazy_choices',
     getter=get_available_styles,
+    short_help=f'Output coloring style (default is "{DEFAULT_STYLE}").',
     help_formatter=format_style_help,
 )
 
@@ -291,6 +327,7 @@ output_processing.add_argument(
 output_processing.add_argument(
     '--unsorted',
     **_unsorted_kwargs,
+    short_help='Disables all sorting while formatting output.',
     help=f"""
     Disables all sorting while formatting output. It is a shortcut for:
 
@@ -301,6 +338,7 @@ output_processing.add_argument(
 output_processing.add_argument(
     '--sorted',
     **_sorted_kwargs,
+    short_help='Re-enables all sorting options while formatting output.',
     help=f"""
     Re-enables all sorting options while formatting output. It is a shortcut for:
 
@@ -312,6 +350,7 @@ output_processing.add_argument(
     '--response-charset',
     metavar='ENCODING',
     type=response_charset_type,
+    short_help='Override the response encoding for terminal display purposes.',
     help="""
     Override the response encoding for terminal display purposes, e.g.:
 
@@ -324,6 +363,7 @@ output_processing.add_argument(
     '--response-mime',
     metavar='MIME_TYPE',
     type=response_mime_type,
+    short_help='Override the response mime type for coloring and formatting for the terminal.',
     help="""
     Override the response mime type for coloring and formatting for the terminal, e.g.:
 
@@ -335,6 +375,7 @@ output_processing.add_argument(
 output_processing.add_argument(
     '--format-options',
     action='append',
+    short_help='Controls output formatting.',
     help="""
     Controls output formatting. Only relevant when formatting is enabled
     through (explicit or implied) --pretty=all or --pretty=format.
@@ -361,13 +402,14 @@ output_processing.add_argument(
 # Output options
 #######################################################################
 
-output_options = options.add_group('Output Options')
+output_options = options.add_group('Output options')
 
 output_options.add_argument(
     '--print',
     '-p',
     dest='output_options',
     metavar='WHAT',
+    short_help='Options to specify what the console output should contain.',
     help=f"""
     String specifying what the output should contain:
 
@@ -390,6 +432,7 @@ output_options.add_argument(
     dest='output_options',
     action='store_const',
     const=OUT_RESP_HEAD,
+    short_help='Print only the response headers.',
     help=f"""
     Print only the response headers. Shortcut for --print={OUT_RESP_HEAD}.
 
@@ -401,6 +444,7 @@ output_options.add_argument(
     dest='output_options',
     action='store_const',
     const=OUT_RESP_META,
+    short_help='Print only the response metadata.',
     help=f"""
     Print only the response metadata. Shortcut for --print={OUT_RESP_META}.
 
@@ -412,6 +456,7 @@ output_options.add_argument(
     dest='output_options',
     action='store_const',
     const=OUT_RESP_BODY,
+    short_help='Print only the response body.',
     help=f"""
     Print only the response body. Shortcut for --print={OUT_RESP_BODY}.
 
@@ -424,20 +469,22 @@ output_options.add_argument(
     dest='verbose',
     action='count',
     default=0,
+    short_help='Make output more verbose.',
     help=f"""
     Verbose output. For the level one (with single `-v`/`--verbose`), print
     the whole request as well as the response. Also print any intermediary
     requests/responses (such as redirects). For the second level and higher,
     print these as well as the response metadata.
 
-    Level one is a shortcut for: --all --print={''.join(BASE_OUTPUT_OPTIONS)}
-    Level two is a shortcut for: --all --print={''.join(OUTPUT_OPTIONS)}
+    Level one is a shortcut for: --all --print={''.join(sorted(BASE_OUTPUT_OPTIONS))}
+    Level two is a shortcut for: --all --print={''.join(sorted(OUTPUT_OPTIONS))}
     """,
 )
 output_options.add_argument(
     '--all',
     default=False,
     action='store_true',
+    short_help='Show any intermediary requests/responses.',
     help="""
     By default, only the final request/response is shown. Use this flag to show
     any intermediary requests/responses as well. Intermediary requests include
@@ -451,19 +498,14 @@ output_options.add_argument(
     '-P',
     dest='output_options_history',
     metavar='WHAT',
-    help="""
-    The same as --print, -p but applies only to intermediary requests/responses
-    (such as redirects) when their inclusion is enabled with --all. If this
-    options is not specified, then they are formatted the same way as the final
-    response.
-
-    """,
+    help=Qualifiers.SUPPRESS,
 )
 output_options.add_argument(
     '--stream',
     '-S',
     action='store_true',
     default=False,
+    short_help='Always stream the response body by line, i.e., behave like `tail -f`.',
     help="""
     Always stream the response body by line, i.e., behave like `tail -f'.
 
@@ -484,6 +526,7 @@ output_options.add_argument(
     type=FileType('a+b'),
     dest='output_file',
     metavar='FILE',
+    short_help='Save output to FILE instead of stdout.',
     help="""
     Save output to FILE instead of stdout. If --download is also set, then only
     the response body is saved to FILE. Other parts of the HTTP exchange are
@@ -497,6 +540,7 @@ output_options.add_argument(
     '-d',
     action='store_true',
     default=False,
+    short_help='Download the body to a file instead of printing it to stdout.',
     help="""
     Do not print the response body to stdout. Rather, download it and store it
     in a file. The filename is guessed unless specified with --output
@@ -510,6 +554,7 @@ output_options.add_argument(
     dest='download_resume',
     action='store_true',
     default=False,
+    short_help='Resume an interrupted download (--output needs to be specified).',
     help="""
     Resume an interrupted download. Note that the --output option needs to be
     specified as well.
@@ -521,6 +566,7 @@ output_options.add_argument(
     '-q',
     action='count',
     default=0,
+    short_help='Do not print to stdout or stderr, except for errors and warnings when provided once.',
     help="""
     Do not print to stdout or stderr, except for errors and warnings when provided once.
     Provide twice to suppress warnings as well.
@@ -544,21 +590,26 @@ sessions.add_argument(
     '--session',
     metavar='SESSION_NAME_OR_PATH',
     type=session_name_validator,
-    help=f"""
+    short_help='Create, or reuse and update a session.',
+    help="""
     Create, or reuse and update a session. Within a session, custom headers,
     auth credential, as well as any cookies sent by the server persist between
     requests.
 
     Session files are stored in:
 
-        {DEFAULT_SESSIONS_DIR}/<HOST>/<SESSION_NAME>.json.
+        [HTTPIE_CONFIG_DIR]/<HOST>/<SESSION_NAME>.json.
 
+    See the following page to find out your default HTTPIE_CONFIG_DIR:
+
+        https://httpie.io/docs/cli/config-file-directory
     """,
 )
 sessions.add_argument(
     '--session-read-only',
     metavar='SESSION_NAME_OR_PATH',
     type=session_name_validator,
+    short_help='Create or read a session without updating it',
     help="""
     Create or read a session without updating it form the request/response
     exchange.
@@ -566,38 +617,52 @@ sessions.add_argument(
     """,
 )
 
+
 #######################################################################
 # Authentication
 #######################################################################
 
 
-def format_auth_help(auth_plugins_mapping):
-    auth_plugins = list(auth_plugins_mapping.values())
-    return """
+def format_auth_help(auth_plugins_mapping, *, isolation_mode: bool = False):
+    text = """
     The authentication mechanism to be used. Defaults to "{default}".
 
-    {types}
+    {auth_types}
+    """
 
-    """.format(
+    auth_plugins = list(auth_plugins_mapping.values())
+    if isolation_mode:
+        auth_plugins = [
+            auth_plugin
+            for auth_plugin in auth_plugins
+            if issubclass(auth_plugin, BuiltinAuthPlugin)
+        ]
+        text += '\n'
+        text += 'To see all available auth types on your system, including ones installed via plugins, run:\n\n'
+        text += '    $ http --auth-type'
+
+    auth_types = '\n\n    '.join(
+        '"{type}": {name}{package}{description}'.format(
+            type=plugin.auth_type,
+            name=plugin.name,
+            package=(
+                ''
+                if issubclass(plugin, BuiltinAuthPlugin)
+                else f' (provided by {plugin.package_name})'
+            ),
+            description=(
+                ''
+                if not plugin.description
+                else '\n      '
+                     + ('\n      '.join(textwrap.wrap(plugin.description)))
+            ),
+        )
+        for plugin in auth_plugins
+    )
+
+    return text.format(
         default=auth_plugins[0].auth_type,
-        types='\n    '.join(
-            '"{type}": {name}{package}{description}'.format(
-                type=plugin.auth_type,
-                name=plugin.name,
-                package=(
-                    ''
-                    if issubclass(plugin, BuiltinAuthPlugin)
-                    else f' (provided by {plugin.package_name})'
-                ),
-                description=(
-                    ''
-                    if not plugin.description
-                    else '\n      '
-                    + ('\n      '.join(textwrap.wrap(plugin.description)))
-                ),
-            )
-            for plugin in auth_plugins
-        ),
+        auth_types=auth_types,
     )
 
 
@@ -608,6 +673,7 @@ authentication.add_argument(
     '-a',
     default=None,
     metavar='USER[:PASS] | TOKEN',
+    short_help='Credentials for the selected (-A) authentication method.',
     help="""
     For username/password based authentication mechanisms (e.g
     basic auth or digest auth) if only the username is provided
@@ -623,16 +689,14 @@ authentication.add_argument(
     getter=plugin_manager.get_auth_plugin_mapping,
     sort=True,
     cache=False,
+    short_help='The authentication mechanism to be used.',
     help_formatter=format_auth_help,
 )
 authentication.add_argument(
     '--ignore-netrc',
     default=False,
     action='store_true',
-    help="""
-    Ignore credentials from .netrc.
-
-    """,
+    short_help='Ignore credentials from .netrc.'
 )
 
 #######################################################################
@@ -645,9 +709,7 @@ network.add_argument(
     '--offline',
     default=False,
     action='store_true',
-    help="""
-    Build the request and print it but don’t actually send it.
-    """,
+    short_help='Build the request and print it but don’t actually send it.'
 )
 network.add_argument(
     '--proxy',
@@ -655,6 +717,7 @@ network.add_argument(
     action='append',
     metavar='PROTOCOL:PROXY_URL',
     type=KeyValueArgType(SEPARATOR_PROXY),
+    short_help='String mapping of protocol to the URL of the proxy.',
     help="""
     String mapping protocol to the URL of the proxy
     (e.g. http:http://foo.bar:3128). You can specify multiple proxies with
@@ -668,16 +731,14 @@ network.add_argument(
     '-F',
     default=False,
     action='store_true',
-    help="""
-    Follow 30x Location redirects.
-
-    """,
+    short_help='Follow 30x Location redirects.'
 )
 
 network.add_argument(
     '--max-redirects',
     type=int,
     default=30,
+    short_help='The maximum number of redirects that should be followed (with --follow).',
     help="""
     By default, requests have a limit of 30 redirects (works with --follow).
 
@@ -687,11 +748,10 @@ network.add_argument(
     '--max-headers',
     type=int,
     default=0,
-    help="""
-    The maximum number of response headers to be read before giving up
-    (default 0, i.e., no limit).
-
-    """,
+    short_help=(
+        'The maximum number of response headers to be read before '
+        'giving up (default 0, i.e., no limit).'
+    )
 )
 
 network.add_argument(
@@ -699,6 +759,7 @@ network.add_argument(
     type=float,
     default=0,
     metavar='SECONDS',
+    short_help='The connection timeout of the request in seconds.',
     help="""
     The connection timeout of the request in seconds.
     The default value is 0, i.e., there is no timeout limit.
@@ -713,6 +774,7 @@ network.add_argument(
     '--check-status',
     default=False,
     action='store_true',
+    short_help='Exit with an error status code if the server replies with an error.',
     help="""
     By default, HTTPie exits with 0 when no network or other fatal errors
     occur. This flag instructs HTTPie to also check the HTTP status code and
@@ -729,20 +791,16 @@ network.add_argument(
     '--path-as-is',
     default=False,
     action='store_true',
-    help="""
-    Bypass dot segment (/../ or /./) URL squashing.
-
-    """,
+    short_help='Bypass dot segment (/../ or /./) URL squashing.'
 )
 network.add_argument(
     '--chunked',
     default=False,
     action='store_true',
-    help="""
-    Enable streaming via chunked transfer encoding.
-    The Transfer-Encoding header is set to chunked.
-
-    """,
+    short_help=(
+        'Enable streaming via chunked transfer encoding. '
+        'The Transfer-Encoding header is set to chunked.'
+    )
 )
 
 #######################################################################
@@ -754,6 +812,7 @@ ssl = options.add_group('SSL')
 ssl.add_argument(
     '--verify',
     default='yes',
+    short_help='If "no", skip SSL verification. If a file path, use it as a CA bundle.',
     help="""
     Set to "no" (or "false") to skip checking the host's SSL certificate.
     Defaults to "yes" ("true"). You can also pass the path to a CA_BUNDLE file
@@ -765,6 +824,7 @@ ssl.add_argument(
     '--ssl',
     dest='ssl_version',
     choices=sorted(AVAILABLE_SSL_VERSION_ARG_MAPPING.keys()),
+    short_help='The desired protocol version to used.',
     help="""
     The desired protocol version to use. This will default to
     SSL v2.3 which will negotiate the highest protocol that both
@@ -774,21 +834,36 @@ ssl.add_argument(
 
     """,
 )
+
+CIPHERS_CURRENT_DEFAULTS = (
+    """
+    See `http --help` for the default ciphers list on you system.
+
+    """
+    if IS_MAN_PAGE else
+    f"""
+    By default, the following ciphers are used on your system:
+
+    {DEFAULT_SSL_CIPHERS_STRING}
+
+    """
+)
 ssl.add_argument(
     '--ciphers',
+    short_help='A string in the OpenSSL cipher list format.',
     help=f"""
 
-    A string in the OpenSSL cipher list format. By default, the following
-    is used:
+    A string in the OpenSSL cipher list format.
 
-    {DEFAULT_SSL_CIPHERS}
+    {CIPHERS_CURRENT_DEFAULTS}
 
-    """,
+    """
 )
 ssl.add_argument(
     '--cert',
     default=None,
     type=readable_file_arg,
+    short_help='Specifies a local cert to use as the client-side SSL certificate.',
     help="""
     You can specify a local cert to use as client side SSL certificate.
     This file may either contain both private key and certificate or you may
@@ -800,6 +875,7 @@ ssl.add_argument(
     '--cert-key',
     default=None,
     type=readable_file_arg,
+    short_help='The private key to use with SSL. Only needed if --cert is given.',
     help="""
     The private key to use with SSL. Only needed if --cert is given and the
     certificate file does not contain the private key.
@@ -811,11 +887,12 @@ ssl.add_argument(
     '--cert-key-pass',
     default=None,
     type=SSLCredentials,
-    help='''
+    short_help='The passphrase to be used to with the given private key.',
+    help="""
     The passphrase to be used to with the given private key. Only needed if --cert-key
     is given and the key file requires a passphrase.
     If not provided, you’ll be prompted interactively.
-    '''
+    """
 )
 
 #######################################################################
@@ -828,50 +905,42 @@ troubleshooting.add_argument(
     '-I',
     action='store_true',
     default=False,
-    help="""
-    Do not attempt to read stdin.
-
-    """,
+    short_help='Do not attempt to read stdin'
 )
 troubleshooting.add_argument(
     '--help',
     action='help',
     default=Qualifiers.SUPPRESS,
-    help="""
-    Show this help message and exit.
-
-    """,
+    short_help='Show this help message and exit.',
+)
+troubleshooting.add_argument(
+    '--manual',
+    action='manual',
+    default=Qualifiers.SUPPRESS,
+    short_help='Show the full manual.',
 )
 troubleshooting.add_argument(
     '--version',
     action='version',
     version=__version__,
-    help="""
-    Show version and exit.
-
-    """,
+    short_help='Show version and exit.',
 )
 troubleshooting.add_argument(
     '--traceback',
     action='store_true',
     default=False,
-    help="""
-    Prints the exception traceback should one occur.
-
-    """,
+    short_help='Prints the exception traceback should one occur.',
 )
 troubleshooting.add_argument(
     '--default-scheme',
     default='http',
-    help="""
-    The default scheme to use if not specified in the URL.
-
-    """,
+    short_help='The default scheme to use if not specified in the URL.'
 )
 troubleshooting.add_argument(
     '--debug',
     action='store_true',
     default=False,
+    short_help='Print useful diagnostic information for bug reports.',
     help="""
     Prints the exception traceback should one occur, as well as other
     information useful for debugging HTTPie itself and for reporting bugs.
